@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _RCLCONFIG_H_INCLUDED_
 #define _RCLCONFIG_H_INCLUDED_
@@ -203,6 +203,7 @@ class RclConfig {
     string getPidfile() const;
     /** Get indexing status file name */
     string getIdxStatusFile() const;
+    string getIdxStopFile() const;
     /** Do path translation according to the ptrans table */
     void urlrewrite(const string& dbdir, string& url) const;
     ConfSimple *getPTrans() {
@@ -213,6 +214,9 @@ class RclConfig {
 
     /** Get list of skipped file names for current keydir */
     vector<string>& getSkippedNames();
+    /** Get list of file name filters for current keydir (only those
+       names indexed) */
+    vector<string>& getOnlyNames();
 
     /** Get list of skipped paths patterns. Doesn't depend on the keydir */
     vector<string> getSkippedPaths() const;
@@ -389,9 +393,14 @@ class RclConfig {
     ParamStale   m_stpsuffstate;
     vector<string> m_stopsuffvec;
 
+    // skippedNames state 
     ParamStale   m_skpnstate;
     vector<string> m_skpnlist;
 
+    // onlyNames state 
+    ParamStale   m_onlnstate;
+    vector<string> m_onlnlist;
+
     // Original current working directory. Set once at init before we do any
     // chdir'ing and used for converting user args to absolute paths.
     static string o_origcwd;
