@@ -7,10 +7,15 @@ using namespace std;
 
 string compute_utf8fn(const RclConfig *config, const string& ifn, bool simple)
 {
+    string lfn(simple ? path_getsimple(ifn) : ifn);
+#ifdef _WIN32
+    // On windows file names are read as UTF16 wchar_t and converted to UTF-8
+    // while scanning directories
+    return lfn;
+#else
     string charset = config->getDefCharset(true);
     string utf8fn; 
     int ercnt;
-    string lfn(simple ? path_getsimple(ifn) : ifn);
     if (!transcode(lfn, utf8fn, charset, "UTF-8", &ercnt)) {
 	LOGERR("compute_utf8fn: fn transcode failure from ["  << charset <<
                "] to UTF-8 for: [" << lfn << "]\n");
@@ -21,4 +26,5 @@ string compute_utf8fn(const RclConfig *config, const string& ifn, bool simple)
     LOGDEB1("compute_utf8fn: transcoded from ["  << lfn << "] to ["  <<
             utf8fn << "] ("  << charset << "->"  << "UTF-8)\n");
     return utf8fn;
+#endif
 }
