@@ -13,7 +13,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the
 #   Free Software Foundation, Inc.,
-#   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ########################################################
 ## Recoll multifilter communication module and utilities
 #
@@ -29,13 +29,40 @@ import shutil
 import getopt
 import rclconfig
 
-PY3 = sys.version > '3'
+PY3 = (sys.version > '3')
+_mswindows = (sys.platform == "win32")
 
 def makebytes(data):
     if type(data) == type(u''):
         return data.encode("UTF-8")
     return data
 
+def subprocfile(fn):
+    # On Windows PY3 the list2cmdline() method in subprocess assumes that
+    # all args are str, and we receive file names as UTF-8. So we need
+    # to convert.
+    # On Unix all list elements get converted to bytes in the C
+    # _posixsubprocess module, nothing to do
+    if PY3 and _mswindows:
+        return fn.decode('UTF-8')
+    else:
+        return fn
+
+def configparamtrue(value):
+    if not value:
+        return False
+    try:
+        ivalue = int(value)
+        if ivalue:
+            return True
+        else:
+            return False
+    except:
+        pass
+    if value[0] in 'tT':
+        return True
+    return False
+
 my_config = rclconfig.RclConfig()
 
 ############################################
@@ -70,14 +97,18 @@ class RclExecM:
             import msvcrt
             msvcrt.setmode(sys.stdout.fileno(), os.O_BINARY)
             msvcrt.setmode(sys.stdin.fileno(), os.O_BINARY)
-        self.debugfile = None
+        self.debugfile = my_config.getConfParam("filterdebuglog")
         if self.debugfile:
             self.errfout = open(self.debugfile, "a")
         else:
             self.errfout = sys.stderr
-        
+    
     def rclog(self, s, doexit = 0, exitvalue = 1):
-        print("RCLMFILT: %s: %s" % (self.myname, s), file=self.errfout)
+        # On windows, and I think that it changed quite recently (Qt change?)
+        # we get stdout as stderr. So don't write at all
+        if self.debugfile or sys.platform != "win32":
+            print("RCLMFILT: %s: %s" % (self.myname, s), file=self.errfout)
+            self.errfout.flush()
         if doexit:
             sys.exit(exitvalue)
 
@@ -229,6 +260,7 @@ class RclExecM:
             else:
                 ok, data, ipath, eof = processor.getnext(params)
         except Exception as err:
+            self.rclog("getipath/next: exception: %s" %err)
             self.answer("", "", eof, RclExecM.fileerror)
             return
 
@@ -369,6 +401,7 @@ def main(proto, extract):
 
     if len(args) != 1:
         usage()
+    path = args[0]
         
     def mimetype_with_file(f):
         cmd = 'file -i "' + f + '"'
@@ -385,11 +418,16 @@ def main(proto, extract):
     def debprint(out, s):
         if not actAsSingle:
             proto.breakwrite(out, makebytes(s+'\n'))
-            
-    params = {'filename:': makebytes(args[0])}
-    # Some filters (e.g. rclaudio) need/get a MIME type from the indexer
-    mimetype = mimetype_with_xdg(args[0])
-    params['mimetype:'] = mimetype
+
+    params = {'filename:': makebytes(path)}
+
+    # Some filters (e.g. rclaudio) need/get a MIME type from the indexer.
+    # We make a half-assed attempt to emulate:
+    mimetype = my_config.mimeType(path)
+    if not mimetype and not _mswindows:
+        mimetype = mimetype_with_file(path)
+    if mimetype:
+        params['mimetype:'] = mimetype
 
     if not extract.openfile(params):
         print("Open error", file=sys.stderr)
