@@ -13,7 +13,7 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, write to the
 #  Free Software Foundation, Inc.,
-#  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 """ Move pages created by the recoll-we extension from the download directory to the recoll web queue.
 
@@ -42,6 +42,8 @@ try:
 except:
     import rclconfig
 
+_mswindows = (sys.platform == "win32")
+
 verbosity = 0
 def logdeb(s):
     if verbosity >= 4:
@@ -114,7 +116,10 @@ if not os.path.isdir(mydir):
 # Get target webqueue recoll directory from recoll configuration
 webqueuedir = config.getConfParam("webqueuedir")
 if not webqueuedir:
-    webqueuedir = "~/.recollweb/ToIndex"
+    if _mswindows:
+        webqueuedir = "~/AppData/Local/RecollWebQueue"
+    else:
+        webqueuedir = "~/.recollweb/ToIndex"
 webqueuedir = os.path.expanduser(webqueuedir)
 os.makedirs(webqueuedir, exist_ok = True)
 
@@ -140,6 +145,6 @@ for hash in cfiles.keys():
         shutil.move(os.path.join(downloadsdir, cfiles[hash]),
                     os.path.join(webqueuedir, newname))
         shutil.move(os.path.join(downloadsdir, mfiles[hash]),
-                    os.path.join(webqueuedir, "." + newname))
+                    os.path.join(webqueuedir, "_" + newname))
 
 
