@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,7 +6,8 @@
 #
 from builtins import range
 import sys, os.path, optparse
-sys.path.append(sys.path[0]+"/msodump.zip")
+sys.path.insert(0, sys.path[0]+"/msodump.zip")
+import traceback
 
 from msodumper import ole, xlsstream, globals, node, xlsmodel, olestream
 from msodumper import xlsparser, msocrypto
@@ -232,7 +233,15 @@ def main ():
     elif options.dump_mode == 'xml':
         dumper.dumpXML()
     elif options.dump_mode == 'canonical-xml' or options.dump_mode == 'cxml':
-        dumper.dumpCanonicalXML()
+        try:
+            dumper.dumpCanonicalXML()
+        except Exception as err:
+            if globals.params.catchExceptions:
+                traceback.print_exc()
+            else:
+                raise
+            globals.error("Dump failed")
+            sys.exit(1)
     else:
         error("unknown dump mode: '%s'\n"%options.dump_mode)
         parser.print_help()
