@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
@@ -77,7 +77,8 @@ bool EXEDocFetcher::makesig(RclConfig* cnf, const Rcl::Doc& idoc, string& sig)
 }
 
 // Lookup bckid in the config and create an appropriate fetcher.
-EXEDocFetcher *exeDocFetcherMake(RclConfig *config, const string& bckid)
+std::unique_ptr<EXEDocFetcher> exeDocFetcherMake(RclConfig *config,
+                                                 const string& bckid)
 {
     // The config we only read once, not gonna change.
     static ConfSimple *bconf;
@@ -122,5 +123,5 @@ EXEDocFetcher *exeDocFetcherMake(RclConfig *config, const string& bckid)
                " not found in exec path or filters dir\n");
         return 0;
     }
-    return new EXEDocFetcher(m);
+    return std::unique_ptr<EXEDocFetcher>(new EXEDocFetcher(m));
 }
