@@ -12,10 +12,12 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
+#include <memory>
+
 #include "log.h"
 #include "rclconfig.h"
 #include "fetcher.h"
@@ -23,22 +25,23 @@
 #include "webqueuefetcher.h"
 #include "exefetcher.h"
 
-DocFetcher *docFetcherMake(RclConfig *config, const Rcl::Doc& idoc)
+std::unique_ptr<DocFetcher> docFetcherMake(RclConfig *config,
+                                           const Rcl::Doc& idoc)
 {
     if (idoc.url.empty()) {
         LOGERR("docFetcherMakeg:: no url in doc!\n" );
-        return 0;
+        return std::unique_ptr<DocFetcher>();
     }
     string backend;
     idoc.getmeta(Rcl::Doc::keybcknd, &backend);
     if (backend.empty() || !backend.compare("FS")) {
-	return new FSDocFetcher;
+	return std::unique_ptr<DocFetcher>(new FSDocFetcher);
 #ifndef DISABLE_WEB_INDEXER
     } else if (!backend.compare("BGL")) {
-	return new WQDocFetcher;
+	return std::unique_ptr<DocFetcher>(new WQDocFetcher);
 #endif
     } else {
-        DocFetcher *f = exeDocFetcherMake(config, backend);
+        std::unique_ptr<DocFetcher> f(exeDocFetcherMake(config, backend));
         if (!f) {
             LOGERR("DocFetcherFactory: unknown backend [" << backend << "]\n");
         }
