@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _FSFETCHER_H_INCLUDED_
 #define _FSFETCHER_H_INCLUDED_
@@ -27,7 +27,8 @@ class FSDocFetcher : public DocFetcher{
     virtual bool fetch(RclConfig* cnf, const Rcl::Doc& idoc, RawDoc& out);
     
     /** Calls stat to retrieve file signature data */
-    virtual bool makesig(RclConfig* cnf, const Rcl::Doc& idoc, string& sig);
+    virtual bool makesig(RclConfig* cnf,const Rcl::Doc& idoc, std::string& sig);
+    virtual DocFetcher::Reason testAccess(RclConfig* cnf, const Rcl::Doc& idoc);
     virtual ~FSDocFetcher() {}
 };
 
