@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef TEST_MIMETYPE
@@ -223,7 +223,7 @@ using namespace std;
 int main(int argc, const char **argv)
 {
     string reason;
-    RclConfig *config = recollinit(0, 0, reason);
+    RclConfig *config = recollinit(0, 0, 0, reason);
 
     if (config == 0 || !config->ok()) {
 	string str = "Configuration problem: ";
