@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef TEST_SUBTREELIST
@@ -110,7 +110,7 @@ int main(int argc, char **argv)
 	Usage();
     top = *argv++;argc--;
     string reason;
-    RclConfig *config = recollinit(0, 0, reason, 0);
+    RclConfig *config = recollinit(0, 0, 0, reason, 0);
     if (!config || !config->ok()) {
 	fprintf(stderr, "Recoll init failed: %s\n", reason.c_str());
 	exit(1);
