@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _MH_EXECM_H_INCLUDED_
 #define _MH_EXECM_H_INCLUDED_
@@ -108,14 +108,14 @@ class MimeHandlerExecMultiple : public MimeHandlerExec {
     // No resources to clean up, the ExecCmd destructor does it.
     virtual ~MimeHandlerExecMultiple() {}
 
-    virtual bool next_document();
+    virtual bool next_document() override;
 
     // skip_to and clear inherited from MimeHandlerExec
 
 protected:
         // This is the only 2nd-level derived handler class. Use call-super.
     virtual bool set_document_file_impl(const std::string& mt,
-                                        const std::string &file_path) {
+                                        const std::string &file_path) override {
         m_filefirst = true;
         return MimeHandlerExec::set_document_file_impl(mt, file_path);
     }
