@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "cstr.h"
@@ -29,17 +29,15 @@
 
 #include <iostream>
 
-#ifndef NO_NAMESPACES
 using namespace std;
-#endif /* NO_NAMESPACES */
-
 
 bool MimeHandlerHtml::set_document_file_impl(const string& mt, const string &fn)
 {
     LOGDEB0("textHtmlToDoc: " << fn << "\n");
     string otext;
-    if (!file_to_string(fn, otext)) {
-	LOGINFO("textHtmlToDoc: cant read: " << fn << "\n");
+    string reason;
+    if (!file_to_string(fn, otext, &reason)) {
+        LOGERR("textHtmlToDoc: cant read: " << fn << ": " << reason << "\n");
 	return false;
     }
     m_filename = fn;
