@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _HTML_H_INCLUDED_
 #define _HTML_H_INCLUDED_
@@ -31,26 +31,24 @@ class MimeHandlerHtml : public RecollFilter {
     }
     virtual ~MimeHandlerHtml() {}
 
-    virtual bool is_data_input_ok(DataInput input) const {
+    virtual bool is_data_input_ok(DataInput input) const override {
 	if (input == DOCUMENT_FILE_NAME || input == DOCUMENT_STRING)
 	    return true;
 	return false;
     }
-    virtual bool next_document();
-    const std::string& get_html() 
-    {
+    virtual bool next_document() override;
+    const std::string& get_html() {
 	return m_html;
     }
-    virtual void clear() {
+    virtual void clear_impl() override {
 	m_filename.erase();
 	m_html.erase();
-	RecollFilter::clear(); 
     }
 protected:
     virtual bool set_document_file_impl(const std::string& mt,
-                                        const std::string &file_path);
+                                        const std::string &file_path) override;
     virtual bool set_document_string_impl(const std::string& mt,
-                                          const std::string &data);
+                                          const std::string &data) override;
 
 private:
     std::string m_filename;
