@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _MAIL_H_INCLUDED_
 #define _MAIL_H_INCLUDED_
@@ -24,35 +24,31 @@
 #include "mimehandler.h"
 
 namespace Binc {
-    class MimeDocument;
-    class MimePart;
+class MimeDocument;
+class MimePart;
 }
 
 class MHMailAttach;
 
 /** 
- * Translate a mail folder file into internal documents (also works
- * for maildir files). This has to keep state while parsing a mail folder
- * file. 
+ * Process a mail message (rfc822) into internal documents.
  */
 class MimeHandlerMail : public RecollFilter {
 public:
     MimeHandlerMail(RclConfig *cnf, const std::string &id);
     virtual ~MimeHandlerMail();
-    virtual bool is_data_input_ok(DataInput input) const {
-	if (input == DOCUMENT_FILE_NAME || input == DOCUMENT_STRING)
-	    return true;
-	return false;
+    virtual bool is_data_input_ok(DataInput input) const override {
+        return (input == DOCUMENT_FILE_NAME || input == DOCUMENT_STRING);
     }
-    virtual bool next_document();
-    virtual bool skip_to_document(const std::string& ipath);
-    virtual void clear();
+    virtual bool next_document() override;
+    virtual bool skip_to_document(const std::string& ipath) override;
+    virtual void clear_impl() override;
 
 protected:
     virtual bool set_document_file_impl(const std::string& mt,
-                                        const std::string& file_path);
+                                        const std::string& file_path) override;
     virtual bool set_document_string_impl(const std::string& mt,
-                                          const std::string& data);
+                                          const std::string& data) override;
 
 private:
     bool processMsg(Binc::MimePart *doc, int depth);
@@ -70,16 +66,16 @@ private:
     std::string::size_type       m_startoftext; 
     std::string                  m_subject; 
     std::vector<MHMailAttach *>  m_attachments;
-    // Additional headers to be process as per config + field name translation
+    // Additional headers to be processed as per config + field name translation
     std::map<std::string, std::string>      m_addProcdHdrs; 
 };
 
 class MHMailAttach {
 public:
-    std::string          m_contentType;
-    std::string          m_filename;
-    std::string          m_charset;
-    std::string          m_contentTransferEncoding;
+    std::string m_contentType;
+    std::string m_filename;
+    std::string m_charset;
+    std::string m_contentTransferEncoding;
     Binc::MimePart *m_part;
 };
 
