@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
@@ -81,6 +81,9 @@ bool MimeHandlerText::set_document_file_impl(const string& mt, const string &fn)
         m_pagesz = size_t(ps);
         if (!readnext())
             return false;
+    } else {
+        LOGINF("MimeHandlerText: file too big (textfilemaxmbs=" << maxmbs <<
+               "), contents will not be indexed: " << fn << endl);
     }
     if (!m_forPreview) {
 	string md5, xmd5;
