@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _MIMEHANDLER_H_INCLUDED_
 #define _MIMEHANDLER_H_INCLUDED_
@@ -115,15 +115,17 @@ public:
 	return m_id;
     }
 
-    // "Call super" anti-pattern again. Must be called from derived
-    // classes which reimplement clear()
-    virtual void clear() {
+    // Classes which need to do local work in clear() need
+    // to implement clear_impl()
+    virtual void clear() final {
+        clear_impl();
 	Dijon::Filter::clear();
 	m_forPreview = m_havedoc = false;
 	m_dfltInputCharset.clear();
 	m_reason.clear();
     }
-
+    virtual void clear_impl() {}
+    
     // This only makes sense if the contents are currently txt/plain
     // It converts from keyorigcharset to UTF-8 and sets keycharset.
     bool txtdcode(const std::string& who);
@@ -177,7 +179,14 @@ extern void returnMimeHandler(RecollFilter *);
 /// off recoll.
 extern void clearMimeHandlerCache();
 
+namespace Rcl {
+    class Doc;
+}
 /// Can this mime type be interned ?
 extern bool canIntern(const std::string mimetype, RclConfig *cfg);
+/// Same, getting MIME from doc
+extern bool canIntern(Rcl::Doc *doc, RclConfig *cfg);
+/// Can this MIME type be opened (has viewer def) ?
+extern bool canOpen(Rcl::Doc *doc, RclConfig *cfg);
 
 #endif /* _MIMEHANDLER_H_INCLUDED_ */
