@@ -14,7 +14,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <string>
@@ -177,7 +177,7 @@ private:
     bool isRecollResult(const QUrl& url, int *num, QString* q);
 
     bool        m_initok;
-    Rcl::Db    *m_rcldb;
+    std::shared_ptr<Rcl::Db> m_rcldb;
     std::string      m_reason;
     bool        m_alwaysdir;
     // english by default else env[RECOLL_KIO_STEMLANG]
