@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 
@@ -23,7 +23,7 @@
 #include <strings.h>
 
 #include <string>
-using namespace std;
+#include <memory>
 
 #include "log.h"
 #include "rcldoc.h"
@@ -33,9 +33,10 @@ using namespace std;
 
 #include "pyrecoll.h"
 
+using namespace std;
+
 // Imported from pyrecoll
 static PyObject *recoll_DocType;
-static RclConfig *rclconfig;
 
 //////////////////////////////////////////////////////////////////////
 /// Extractor object code
@@ -43,7 +44,7 @@ typedef struct {
     PyObject_HEAD
     /* Type-specific fields go here. */
     FileInterner *xtr;
-    RclConfig *rclconfig;
+    std::shared_ptr<RclConfig> rclconfig;
     recoll_DocObject *docobject;
 } rclx_ExtractorObject;
 
@@ -54,6 +55,7 @@ Extractor_dealloc(rclx_ExtractorObject *self)
     if (self->docobject) {
         Py_DECREF(&self->docobject);
     }
+    self->rclconfig.reset();
     delete self->xtr;
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
@@ -67,7 +69,6 @@ Extractor_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (self == 0) 
 	return 0;
     self->xtr = 0;
-    self->rclconfig = 0;
     self->docobject = 0;
     return (PyObject *)self;
 }
@@ -91,7 +92,7 @@ Extractor_init(rclx_ExtractorObject *self, PyObject *args, PyObject *kwargs)
     Py_INCREF(dobj);
 
     self->rclconfig = dobj->rclconfig;
-    self->xtr = new FileInterner(*dobj->doc, self->rclconfig, 
+    self->xtr = new FileInterner(*dobj->doc, self->rclconfig.get(), 
 				 FileInterner::FIF_forPreview);
     return 0;
 }
@@ -199,7 +200,7 @@ Extractor_idoctofile(rclx_ExtractorObject* self, PyObject *args,
            mimetype << "] doc mimetype [" << self->docobject->doc->mimetype <<
            "\n");
     if (ipath.empty() && !mimetype.compare(self->docobject->doc->mimetype)) {
-        status = FileInterner::idocToFile(temp, outfile, self->rclconfig,
+        status = FileInterner::idocToFile(temp, outfile, self->rclconfig.get(),
                                                *self->docobject->doc);
     } else {
         self->xtr->setTargetMType(mimetype);
@@ -324,19 +325,21 @@ initrclextract(void)
 #endif
 {
     // We run recollinit. It's responsible for initializing some static data
-    // which is distinct from pyrecoll's as we're separately dlopened
+    // which is distinct from pyrecoll's as we're separately dlopened.
+    // The rclconfig object is not used, we'll get the config
+    // data from the objects out of the recoll module.
+    // Unfortunately, as we're not getting the actual config directory
+    // from pyrecoll (we could, through a capsule), this needs at
+    // least an empty default configuration directory to work.
     string reason;
-    rclconfig = recollinit(0, 0, reason, 0);
+    RclConfig *rclconfig = recollinit(RCLINIT_PYTHON, 0, 0, reason, 0);
     if (rclconfig == 0) {
 	PyErr_SetString(PyExc_EnvironmentError, reason.c_str());
 	INITERROR;
+    } else {
+        delete rclconfig;
     }
-    if (!rclconfig->ok()) {
-	PyErr_SetString(PyExc_EnvironmentError, 
-			"Recoll init error: bad environment ?");
-	INITERROR;
-    }
-
+        
 #if PY_MAJOR_VERSION >= 3
     PyObject *module = PyModule_Create(&moduledef);
 #else
