@@ -12,20 +12,23 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _PYRECOLL_H_INCLUDED_
 #define _PYRECOLL_H_INCLUDED_
 
 #include <Python.h>
 
+#include <memory>
+
 class RclConfig;
+
 typedef struct {
     PyObject_HEAD
     /* Type-specific fields go here. */
     Rcl::Doc *doc;
     /* Each doc object has a pointer to the global config, for convenience */
-    RclConfig *rclconfig; 
+    std::shared_ptr<RclConfig> rclconfig; 
 } recoll_DocObject;
 
 #define PYRECOLL_PACKAGE "recoll."
