@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
@@ -474,6 +474,7 @@ void AdvSearch::runSearch()
     }
     saveCnf();
     g_advshistory && g_advshistory->push(sdata);
+    emit setDescription("");
     emit startSearch(sdata, false);
 }
 
