@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _ADVSEARCH_W_H_INCLUDED_
 #define _ADVSEARCH_W_H_INCLUDED_
@@ -67,7 +67,8 @@ public slots:
 
 signals:
     void startSearch(std::shared_ptr<Rcl::SearchData>, bool);
-
+    void setDescription(QString);
+    
 private:
     virtual void init();
     std::vector<SearchClauseW *> m_clauseWins;
