@@ -12,11 +12,12 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
 #include <cstdlib>
+#include <list>
 
 #include <qapplication.h>
 #include <qtranslator.h>
@@ -29,6 +30,7 @@
 #include <QLocale>
 #include <QLibraryInfo>
 #include <QFileDialog>
+#include <QUrl>
 
 #include "rcldb.h"
 #include "rclconfig.h"
@@ -49,7 +51,9 @@
 extern RclConfig *theconfig;
 
 std::mutex thetempfileslock;
-static vector<TempFile>  o_tempfiles;
+// Use a list not a vector so that contained objects have stable
+// addresses when extending.
+static list<TempFile>  o_tempfiles;
 /* Keep an array of temporary files for deletion at exit. It happens that we
    erase some of them before exiting (ie: when closing a preview tab), we don't 
    reuse the array holes for now */
@@ -80,7 +84,7 @@ void deleteAllTempFiles()
     Uncomp::clearcache();
 }
 
-Rcl::Db *rcldb;
+std::shared_ptr<Rcl::Db> rcldb;
 int recollNeedsExit;
 RclMain *mainWindow;
 
@@ -92,14 +96,11 @@ void startManual(const string& helpindex)
 
 bool maybeOpenDb(string &reason, bool force, bool *maindberror)
 {
-    LOGDEB2("maybeOpenDb: force "  << (force) << "\n" );
-    if (!rcldb) {
-        reason = "Internal error: db not created";
-        return false;
-    }
+    LOGDEB2("maybeOpenDb: force " << force << "\n");
 
-    if (force)
-        rcldb->close();
+    if (force) {
+        rcldb = std::shared_ptr<Rcl::Db>(new Rcl::Db(theconfig));
+    }
     rcldb->rmQueryDb("");
     for (const auto& dbdir : prefs.activeExtraDbs) {
         LOGDEB("main: adding [" << dbdir << "]\n");
@@ -129,7 +130,7 @@ bool getStemLangs(vector<string>& vlangs)
     string reason;
     if (maybeOpenDb(reason)) {
         vlangs = rcldb->getStemLangs();
-        LOGDEB0("getStemLangs: from index: "  << (stringsToString(vlangs)) << "\n" );
+        LOGDEB0("getStemLangs: from index: " << stringsToString(vlangs) <<"\n");
         return true;
     } else {
         // Cant get the langs from the index. Maybe it just does not
@@ -143,10 +144,11 @@ bool getStemLangs(vector<string>& vlangs)
     }
 }
 
+// This is never called because we _Exit() in rclmain_w.cpp
 static void recollCleanup()
 {
     LOGDEB2("recollCleanup: closing database\n" );
-    deleteZ(rcldb);
+    rcldb.reset();
     deleteZ(theconfig);
 
     deleteAllTempFiles();
@@ -182,6 +184,7 @@ static int    op_flags;
 #define OPT_q 0x80      
 #define OPT_t 0x100      
 #define OPT_v 0x200     
+#define OPT_w 0x400
 
 static const char usage [] =
     "\n"
@@ -202,6 +205,7 @@ static const char usage [] =
     "       explicitly as -t (not ie, -at), and -q <query> MUST\n"
     "       be last on the command line if this is used.\n"
     "       Use -t -h to see the additional non-gui options\n"
+    "  -w : open minimized\n"
     "recoll -v : print version\n"
     "recoll <url>\n"
     "   This is used to open a recoll url (including an ipath), and called\n"
@@ -229,7 +233,21 @@ int main(int argc, char **argv)
         }
     }
 
+#ifdef USING_WEBENGINE
+    // This is necessary for allowing webengine to load local resources (icons)
+    // It is not an issue because we never access remote sites.
+    char arg_disable_web_security[] = "--disable-web-security";
+    int appargc = argc + 1;
+    char** appargv = new char*[appargc+1];
+    for(int i = 0; i < argc; i++) {
+        appargv[i] = argv[i];
+    }
+    appargv[argc] = arg_disable_web_security;
+    appargv[argc+1] = nullptr;
+    QApplication app(appargc, appargv);
+#else
     QApplication app(argc, argv);
+#endif
 
     QCoreApplication::setOrganizationName("Recoll.org");
     QCoreApplication::setApplicationName("recoll");
@@ -238,61 +256,70 @@ int main(int argc, char **argv)
     string a_lang;
     string question;
     string urltoview;
-    
-    thisprog = argv[0];
-    argc--; argv++;
 
-    while (argc > 0 && **argv == '-') {
-        (*argv)++;
-        if (!(**argv))
+    // Avoid disturbing argc and argv. Especially, setting argc to 0
+    // prevents WM_CLASS to be set from argv[0] (it appears that qt
+    // keeps a ref to argc, and that it is used at exec() time to set
+    // WM_CLASS from argv[0]). Curiously, it seems that the argv
+    // pointer can be modified without consequences, but we use a copy
+    // to play it safe
+    int myargc = argc;
+    char **myargv = argv;
+    thisprog = myargv[0];
+    myargc--; myargv++;
+    
+    while (myargc > 0 && **myargv == '-') {
+        (*myargv)++;
+        if (!(**myargv))
             Usage();
-        while (**argv)
-            switch (*(*argv)++) {
+        while (**myargv)
+            switch (*(*myargv)++) {
             case 'a': op_flags |= OPT_a; break;
-            case 'c':   op_flags |= OPT_c; if (argc < 2)  Usage();
-                a_config = *(++argv);
-                argc--; goto b1;
+            case 'c':   op_flags |= OPT_c; if (myargc < 2)  Usage();
+                a_config = *(++myargv);
+                myargc--; goto b1;
             case 'f': op_flags |= OPT_f; break;
             case 'h': op_flags |= OPT_h; Usage();break;
-            case 'L':   op_flags |= OPT_L; if (argc < 2)  Usage();
-                a_lang = *(++argv);
-                argc--; goto b1;
+            case 'L':   op_flags |= OPT_L; if (myargc < 2)  Usage();
+                a_lang = *(++myargv);
+                myargc--; goto b1;
             case 'l': op_flags |= OPT_l; break;
             case 'o': op_flags |= OPT_o; break;
-            case 'q':   op_flags |= OPT_q; if (argc < 2)  Usage();
-                question = *(++argv);
-                argc--; goto b1;
+            case 'q':   op_flags |= OPT_q; if (myargc < 2)  Usage();
+                question = *(++myargv);
+                myargc--; goto b1;
+            case 't': op_flags |= OPT_t; break;
             case 'v': op_flags |= OPT_v;
                 fprintf(stdout, "%s\n", Rcl::version_string().c_str());
                 return 0;
-            case 't': op_flags |= OPT_t; break;
+            case 'w': op_flags |= OPT_w; break;
             default: Usage();
             }
-    b1: argc--; argv++;
+    b1: myargc--; myargv++;
     }
 
     // If -q was given, all remaining non-option args are concatenated
     // to the query. This is for the common case recoll -q x y z to
     // avoid needing quoting "x y z"
     if (op_flags & OPT_q)
-        while (argc > 0) {
+        while (myargc > 0) {
             question += " ";
-            question += *argv++;
-            argc--;
+            question += *myargv++;
+            myargc--;
         }
 
     // Else the remaining argument should be an URL to be opened
-    if (argc == 1) {
-        urltoview = *argv++;argc--;
+    if (myargc == 1) {
+        urltoview = *myargv++;myargc--;
         if (urltoview.compare(0, 7, cstr_fileu)) {
             Usage();
         }
-    } else if (argc > 0)
+    } else if (myargc > 0)
         Usage();
 
 
     string reason;
-    theconfig = recollinit(recollCleanup, 0, reason, &a_config);
+    theconfig = recollinit(0, recollCleanup, 0, reason, &a_config);
     if (!theconfig || !theconfig->ok()) {
         QString msg = "Configuration problem: ";
         msg += QString::fromUtf8(reason.c_str());
@@ -361,9 +388,17 @@ int main(int argc, char **argv)
         exit(1);
     }
 
-    rcldb = new Rcl::Db(theconfig);
+    maybeOpenDb(reason);
 
-    mainWindow->show();
+    if (op_flags & OPT_w) {
+        mainWindow->showMinimized();
+    } else {
+        switch (prefs.showmode) {
+        case PrefsPack::SHOW_NORMAL: mainWindow->show(); break;
+        case PrefsPack::SHOW_MAX: mainWindow->showMaximized(); break;
+        case PrefsPack::SHOW_FULL: mainWindow->showFullScreen(); break;
+        }
+    }
     QTimer::singleShot(0, mainWindow, SLOT(initDbOpen()));
 
     // Connect exit handlers etc.. Beware, apparently this must come
@@ -394,11 +429,31 @@ int main(int argc, char **argv)
     return app.exec();
 }
 
-QString myGetFileName(bool isdir, QString caption, bool filenosave)
+QString myGetFileName(bool isdir, QString caption, bool filenosave,
+                      QString dirloc, QString dfltnm)
 {
-    LOGDEB1("myFileDialog: isdir "  << (isdir) << "\n" );
+    LOGDEB1("myFileDialog: isdir " << isdir << "\n");
     QFileDialog dialog(0, caption);
 
+#ifdef _WIN32
+    // The default initial directory on WIndows is the Recoll install,
+    // which is not appropriate. Change it, only for the first call
+    // (next will start with the previous selection).
+    static bool first{true};
+    if (first) {
+        first = false;
+        // See https://doc.qt.io/qt-5/qfiledialog.html#setDirectoryUrl
+        // about the clsid magic (this one points to the desktop).
+        dialog.setDirectoryUrl(
+            QUrl("clsid:B4BFCC3A-DB2C-424C-B029-7FE99A87C641"));
+    }
+#endif
+    if (!dirloc.isEmpty()) {
+        dialog.setDirectory(dirloc);
+    }
+    if (!dfltnm.isEmpty()) {
+        dialog.selectFile(dfltnm);
+    }
     if (isdir) {
         dialog.setFileMode(QFileDialog::Directory);
         dialog.setOptions(QFileDialog::ShowDirsOnly);
@@ -422,4 +477,3 @@ QString myGetFileName(bool isdir, QString caption, bool filenosave)
     }
     return QString();
 }
-
