@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include <string>
 
@@ -62,6 +62,7 @@ void LoadThread::run()
         } else {
             fdoc.mimetype = interner.getMimetype();
             mst.getMissingExternal(missing);
+            explain = FileInterner::tryGetReason(&m_config, m_idoc);
             status = -1;
         }
     } catch (CancelExcept) {
