@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
@@ -55,21 +55,30 @@ void RclMain::updateIdxStatus()
     }
     msg += phs + " ";
     if (status.phase == DbIxStatus::DBIXS_FILES) {
-	char cnts[100];
-	if (status.dbtotdocs > 0) {
-	    sprintf(cnts, "(%d docs/%d files/%d errors/%d tot files) ",
-                    status.docsdone, status.filesdone, status.fileerrors,
-		    status.totfiles);
+        QString sdocs = status.docsdone > 1 ?tr("documents") : tr("document");
+        QString sfiles = status.filesdone > 1 ? tr("files") : tr("file");
+        QString serrors = status.fileerrors > 1 ? tr("errors") : tr("error");
+        QString stats;
+        if (status.dbtotdocs > 0) {
+            stats = QString("(%1 ") + sdocs + "/%2 " + sfiles +
+                "/%3 " + serrors + "/%4 " + tr("total files)");
+            stats = stats.arg(status.docsdone).arg(status.filesdone).
+                arg(status.fileerrors).arg(status.totfiles);
         } else {
-	    sprintf(cnts, "(%d docs/%d files/%d errors) ",
-                    status.docsdone, status.filesdone, status.fileerrors);
+            stats = QString("(%1 ") + sdocs + "/%2 " + sfiles +
+                "/%3 " + serrors + ") ";
+            stats = stats.arg(status.docsdone).arg(status.filesdone).
+                arg(status.fileerrors);
         }
-	msg += QString::fromUtf8(cnts) + " ";
+        msg += stats + " ";
     }
     string mf;int ecnt = 0;
     string fcharset = theconfig->getDefCharset(true);
-    if (!transcode(status.fn, mf, fcharset, "UTF-8", &ecnt) || ecnt) {
-	mf = url_encode(status.fn, 0);
+    // If already UTF-8 let it be, else try to transcode, or url-encode
+    if (!transcode(status.fn, mf, "UTF-8", "UTF-8", &ecnt) || ecnt) {
+        if (!transcode(status.fn, mf, fcharset, "UTF-8", &ecnt) || ecnt) {
+            mf = url_encode(status.fn, 0);
+        }
     }
     msg += QString::fromUtf8(mf.c_str());
     statusBar()->showMessage(msg, 4000);
@@ -80,11 +89,18 @@ void RclMain::updateIdxStatus()
 void RclMain::periodic100()
 {
     LOGDEB2("Periodic100\n" );
+    if (!m_idxreasontmp || !m_idxreasontmp->ok()) {
+        // We just store the pointer and let the tempfile cleaner deal
+        // with delete on exiting
+        TempFile temp(".txt");
+        m_idxreasontmp = rememberTempFile(temp);
+    }
+
     if (m_idxproc) {
-	// An indexing process was launched. If its' done, see status.
-	int status;
-	bool exited = m_idxproc->maybereap(&status);
-	if (exited) {
+        // An indexing process was launched. If its' done, see status.
+        int status;
+        bool exited = m_idxproc->maybereap(&status);
+        if (exited) {
             QString reasonmsg;
             if (m_idxreasontmp && m_idxreasontmp->ok()) {
                 string reasons;
@@ -101,8 +117,8 @@ void RclMain::periodic100()
                     }
                 }
             }
-	    deleteZ(m_idxproc);
-	    if (status) {
+            deleteZ(m_idxproc);
+            if (status) {
                 if (m_idxkilled) {
                     QMessageBox::warning(0, "Recoll", 
                                          tr("Indexing interrupted"));
@@ -115,58 +131,58 @@ void RclMain::periodic100()
                     }
                     QMessageBox::warning(0, "Recoll", msg);
                 }
-	    } else {
-		// On the first run, show missing helpers. We only do this once
-		if (m_firstIndexing)
-		    showMissingHelpers();
+            } else {
+                // On the first run, show missing helpers. We only do this once
+                if (m_firstIndexing)
+                    showMissingHelpers();
                 if (!reasonmsg.isEmpty()) {
                     QString msg = tr("Non-fatal indexing message: ");
                     msg.append(reasonmsg);
                     QMessageBox::warning(0, "Recoll", msg);
                 }
-	    }
-	    string reason;
-	    maybeOpenDb(reason, 1);
-	} else {
-	    // update/show status even if the status file did not
-	    // change (else the status line goes blank during
-	    // lengthy operations).
-	    updateIdxStatus();
-	}
+            }
+            string reason;
+            maybeOpenDb(reason, 1);
+        } else {
+            // update/show status even if the status file did not
+            // change (else the status line goes blank during
+            // lengthy operations).
+            updateIdxStatus();
+        }
     }
     // Update the "start/stop indexing" menu entry, can't be done from
     // the "start/stop indexing" slot itself
     IndexerState prevstate = m_indexerState;
     if (m_idxproc) {
-	m_indexerState = IXST_RUNNINGMINE;
-	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
-	fileToggleIndexingAction->setEnabled(true);
-	fileRebuildIndexAction->setEnabled(false);
+        m_indexerState = IXST_RUNNINGMINE;
+        fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+        fileToggleIndexingAction->setEnabled(true);
+        fileRebuildIndexAction->setEnabled(false);
         actionSpecial_Indexing->setEnabled(false);
-	periodictimer->setInterval(200);
+        periodictimer->setInterval(200);
     } else {
-	Pidfile pidfile(theconfig->getPidfile());
+        Pidfile pidfile(theconfig->getPidfile());
         pid_t pid = pidfile.open();
         fileBumpIndexingAction->setEnabled(false);
         if (pid == getpid()) {
             // Locked by me
-	    m_indexerState = IXST_NOTRUNNING;
-	    fileToggleIndexingAction->setText(tr("Index locked"));
-	    fileToggleIndexingAction->setEnabled(false);
-	    fileRebuildIndexAction->setEnabled(false);
+            m_indexerState = IXST_NOTRUNNING;
+            fileToggleIndexingAction->setText(tr("Index locked"));
+            fileToggleIndexingAction->setEnabled(false);
+            fileRebuildIndexAction->setEnabled(false);
             actionSpecial_Indexing->setEnabled(false);
-	    periodictimer->setInterval(1000);
+            periodictimer->setInterval(1000);
         } else if (pid == 0) {
-	    m_indexerState = IXST_NOTRUNNING;
-	    fileToggleIndexingAction->setText(tr("Update &Index"));
-	    fileToggleIndexingAction->setEnabled(true);
-	    fileRebuildIndexAction->setEnabled(true);
+            m_indexerState = IXST_NOTRUNNING;
+            fileToggleIndexingAction->setText(tr("Update &Index"));
+            fileToggleIndexingAction->setEnabled(true);
+            fileRebuildIndexAction->setEnabled(true);
             actionSpecial_Indexing->setEnabled(true);
-	    periodictimer->setInterval(1000);
-	} else {
-	    // Real time or externally started batch indexer running
-	    m_indexerState = IXST_RUNNINGNOTMINE;
-	    fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+            periodictimer->setInterval(1000);
+        } else {
+            // Real time or externally started batch indexer running
+            m_indexerState = IXST_RUNNINGNOTMINE;
+            fileToggleIndexingAction->setText(tr("Stop &Indexing"));
             DbIxStatus status;
             readIdxStatus(theconfig, status);
             if (status.hasmonitor) {
@@ -174,36 +190,36 @@ void RclMain::periodic100()
                 // incremental pass
                 fileBumpIndexingAction->setEnabled(true);
             }
-	    fileToggleIndexingAction->setEnabled(true);
-	    fileRebuildIndexAction->setEnabled(false);
+            fileToggleIndexingAction->setEnabled(true);
+            fileRebuildIndexAction->setEnabled(false);
             actionSpecial_Indexing->setEnabled(false);
-	    periodictimer->setInterval(200);
-	}	    
+            periodictimer->setInterval(200);
+        }           
     }
 
     if ((prevstate == IXST_RUNNINGMINE || prevstate == IXST_RUNNINGNOTMINE)
         && m_indexerState == IXST_NOTRUNNING) {
-        showTrayMessage("Indexing done");
+        showTrayMessage(tr("Indexing done"));
     }
 
     // Possibly cleanup the dead viewers
     for (vector<ExecCmd*>::iterator it = m_viewers.begin();
-	 it != m_viewers.end(); it++) {
-	int status;
-	if ((*it)->maybereap(&status)) {
-	    deleteZ(*it);
-	}
+         it != m_viewers.end(); it++) {
+        int status;
+        if ((*it)->maybereap(&status)) {
+            deleteZ(*it);
+        }
     }
     vector<ExecCmd*> v;
     for (vector<ExecCmd*>::iterator it = m_viewers.begin();
-	 it != m_viewers.end(); it++) {
-	if (*it)
-	    v.push_back(*it);
+         it != m_viewers.end(); it++) {
+        if (*it)
+            v.push_back(*it);
     }
     m_viewers = v;
 
     if (recollNeedsExit)
-	fileExit();
+        fileExit();
 }
 
 bool RclMain::checkIdxPaths()
@@ -213,7 +229,10 @@ bool RclMain::checkIdxPaths()
     ExecCmd::backtick(args, badpaths);
     if (!badpaths.empty()) {
         int rep = QMessageBox::warning(
-            0, tr("Bad paths"), tr("Bad paths in configuration file:\n") +
+            0, tr("Bad paths"),
+            tr("Empty or non-existant paths in configuration file. "
+               "Click Ok to start indexing anyway "
+               "(absent data will not be purged from the index):\n") +
             QString::fromLocal8Bit(badpaths.c_str()),
             QMessageBox::Ok, QMessageBox::Cancel, QMessageBox::NoButton);
         if (rep == QMessageBox::Cancel)
@@ -227,55 +246,45 @@ bool RclMain::checkIdxPaths()
 // re-enabled by the indexing status check
 void RclMain::toggleIndexing()
 {
-    if (!m_idxreasontmp || !m_idxreasontmp->ok()) {
-        // We just store the pointer and let the tempfile cleaner deal
-        // with delete on exiting
-        TempFile temp(".txt");
-        m_idxreasontmp = rememberTempFile(temp);
-    }
-    
     switch (m_indexerState) {
     case IXST_RUNNINGMINE:
-	if (m_idxproc) {
-	    // Indexing was in progress, request stop. Let the periodic
-	    // routine check for the results.
+        if (m_idxproc) {
+            // Indexing was in progress, request stop. Let the periodic
+            // routine check for the results.
             if (m_idxproc->requestChildExit()) {
                 m_idxkilled = true;
             }
-	}
-	break;
+        }
+        break;
     case IXST_RUNNINGNOTMINE:
     {
-#ifdef _WIN32
-        QMessageBox::warning(0, tr("Warning"),
-                             tr("The current indexing process "
-                                "was not started from this "
-                                "interface, can't kill it"),
-                             QMessageBox::Ok, QMessageBox::NoButton);
-#else
-	int rep = 
-	    QMessageBox::information(
+        int rep = 
+            QMessageBox::information(
                 0, tr("Warning"), 
                 tr("The current indexing process was not started from this "
                    "interface. Click Ok to kill it "
                    "anyway, or Cancel to leave it alone"),
                 QMessageBox::Ok, QMessageBox::Cancel, QMessageBox::NoButton);
-	if (rep == QMessageBox::Ok) {
-	    Pidfile pidfile(theconfig->getPidfile());
-	    pid_t pid = pidfile.open();
-	    if (pid > 0)
-		kill(pid, SIGTERM);
-	}
-#endif
+        if (rep == QMessageBox::Ok) {
+#ifdef _WIN32
+            // No simple way to signal the process. Use the stop file
+            ::close(::creat(theconfig->getIdxStopFile().c_str(), 0666));
+#else
+            Pidfile pidfile(theconfig->getPidfile());
+            pid_t pid = pidfile.open();
+            if (pid > 0)
+                kill(pid, SIGTERM);
+#endif // !_WIN32
+        }
     }
     break;
     case IXST_NOTRUNNING:
     {
-	// Could also mean that no helpers are missing, but then we
-	// won't try to show a message anyway (which is what
-	// firstIndexing is used for)
-	string mhd;
-	m_firstIndexing = !theconfig->getMissingHelperDesc(mhd);
+        // Could also mean that no helpers are missing, but then we
+        // won't try to show a message anyway (which is what
+        // firstIndexing is used for)
+        string mhd;
+        m_firstIndexing = !theconfig->getMissingHelperDesc(mhd);
 
         if (!checkIdxPaths()) {
             return;
@@ -285,8 +294,8 @@ void RclMain::toggleIndexing()
             args.push_back("-R");
             args.push_back(m_idxreasontmp->filename());
         }
-	m_idxproc = new ExecCmd;
-	m_idxproc->startExec("recollindex", args, false, false);
+        m_idxproc = new ExecCmd;
+        m_idxproc->startExec("recollindex", args, false, false);
     }
     break;
     case IXST_UNKNOWN:
@@ -303,7 +312,10 @@ void RclMain::bumpIndexing()
         string cmd("touch ");
         string path = path_cat(theconfig->getConfDir(), "recoll.conf");
         cmd += path;
-        system(cmd.c_str());
+        int status;
+        if ((status = system(cmd.c_str()))) {
+            cerr << cmd << " failed with status " << status << endl;
+        }
     }
 }
 #else
@@ -324,6 +336,12 @@ static void delay(int millisecondsWait)
 
 void RclMain::rebuildIndex()
 {
+    if (!m_idxreasontmp || !m_idxreasontmp->ok()) {
+        // We just store the pointer and let the tempfile cleaner deal
+        // with delete on exiting
+        TempFile temp(".txt");
+        m_idxreasontmp = rememberTempFile(temp);
+    }
     if (m_indexerState == IXST_UNKNOWN) {
         delay(1500);
     }
@@ -331,21 +349,21 @@ void RclMain::rebuildIndex()
     case IXST_UNKNOWN:
     case IXST_RUNNINGMINE:
     case IXST_RUNNINGNOTMINE:
-	return; //?? Should not have been called
+        return; //?? Should not have been called
     case IXST_NOTRUNNING:
     {
         if (m_idxproc) {
             LOGERR("RclMain::rebuildIndex: current indexer exec not null\n" );
             return;
         }
-	int rep = 
-	    QMessageBox::warning(0, tr("Erasing index"), 
-				     tr("Reset the index and start "
-					"from scratch ?"),
-					 QMessageBox::Ok,
-					 QMessageBox::Cancel,
-					 QMessageBox::NoButton);
-	if (rep == QMessageBox::Ok) {
+        int rep = 
+            QMessageBox::warning(0, tr("Erasing index"), 
+                                 tr("Reset the index and start "
+                                    "from scratch ?"),
+                                 QMessageBox::Ok,
+                                 QMessageBox::Cancel,
+                                 QMessageBox::NoButton);
+        if (rep == QMessageBox::Ok) {
 #ifdef _WIN32
             // Under windows, it is necessary to close the db here,
             // else Xapian won't be able to do what it wants with the
@@ -366,24 +384,24 @@ void RclMain::rebuildIndex()
                 rcldb->close();
             }
 #endif // _WIN32
-	    // Could also mean that no helpers are missing, but then we
-	    // won't try to show a message anyway (which is what
-	    // firstIndexing is used for)
-	    string mhd;
-	    m_firstIndexing = !theconfig->getMissingHelperDesc(mhd);
+            // Could also mean that no helpers are missing, but then we
+            // won't try to show a message anyway (which is what
+            // firstIndexing is used for)
+            string mhd;
+            m_firstIndexing = !theconfig->getMissingHelperDesc(mhd);
 
             if (!checkIdxPaths()) {
                 return;
             }
             
-	    vector<string> args{"-c", theconfig->getConfDir(), "-z"};
+            vector<string> args{"-c", theconfig->getConfDir(), "-z"};
             if (m_idxreasontmp && m_idxreasontmp->ok()) {
                 args.push_back("-R");
                 args.push_back(m_idxreasontmp->filename());
             }
-	    m_idxproc = new ExecCmd;
-	    m_idxproc->startExec("recollindex", args, false, false);
-	}
+            m_idxproc = new ExecCmd;
+            m_idxproc->startExec("recollindex", args, false, false);
+        }
     }
     break;
     }
@@ -397,7 +415,7 @@ void SpecIdxW::onBrowsePB_clicked()
 
 bool SpecIdxW::noRetryFailed()
 {
-    return noRetryFailedCB->isChecked();
+    return !retryFailedCB->isChecked();
 }
 
 bool SpecIdxW::eraseFirst()
@@ -441,11 +459,17 @@ static string execToString(const string& cmd, const vector<string>& args)
 void RclMain::specialIndex()
 {
     LOGDEB("RclMain::specialIndex\n" );
+    if (!m_idxreasontmp || !m_idxreasontmp->ok()) {
+        // We just store the pointer and let the tempfile cleaner deal
+        // with delete on exiting
+        TempFile temp(".txt");
+        m_idxreasontmp = rememberTempFile(temp);
+    }
     switch (m_indexerState) {
     case IXST_UNKNOWN:
     case IXST_RUNNINGMINE:
     case IXST_RUNNINGNOTMINE:
-	return; //?? Should not have been called
+        return; //?? Should not have been called
     case IXST_NOTRUNNING:
     default:
         break;
@@ -473,18 +497,15 @@ void RclMain::specialIndex()
             args.push_back("-Z");
         } else {
             args.push_back("-e");
+            // -e also needs -i, else we don't reindex, just erase
+            args.push_back("-i");
         }
     } 
 
-    // The default for retrying differ depending if -r is set
-    if (top.empty()) {
-        if (!specidx->noRetryFailed()) {
-            args.push_back("-k");
-        }
+    if (!specidx->noRetryFailed()) {
+        args.push_back("-k");
     } else {
-        if (specidx->noRetryFailed()) {
-            args.push_back("-K");
-        }
+        args.push_back("-K");
     }
         
     vector<string> selpats = specidx->selpatterns();
@@ -512,24 +533,28 @@ void RclMain::specialIndex()
 void RclMain::updateIdxForDocs(vector<Rcl::Doc>& docs)
 {
     if (m_idxproc) {
-	QMessageBox::warning(0, tr("Warning"), 
-			     tr("Can't update index: indexer running"),
-			     QMessageBox::Ok, QMessageBox::NoButton);
-	return;
+        QMessageBox::warning(0, tr("Warning"), 
+                             tr("Can't update index: indexer running"),
+                             QMessageBox::Ok, QMessageBox::NoButton);
+        return;
     }
-	
+        
     vector<string> paths;
     if (Rcl::docsToPaths(docs, paths)) {
-	vector<string> args{"-c", theconfig->getConfDir(), "-e", "-i"};
+        vector<string> args{"-c", theconfig->getConfDir(), "-i",};
         if (m_idxreasontmp && m_idxreasontmp->ok()) {
             args.push_back("-R");
             args.push_back(m_idxreasontmp->filename());
         }
-	args.insert(args.end(), paths.begin(), paths.end());
-	m_idxproc = new ExecCmd;
-	m_idxproc->startExec("recollindex", args, false, false);
-	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
+        args.insert(args.end(), paths.begin(), paths.end());
+        m_idxproc = new ExecCmd;
+        m_idxproc->startExec("recollindex", args, false, false);
+        // Call periodic100 to update the menu entries states
+        periodic100();
+    } else {
+        QMessageBox::warning(0, tr("Warning"), 
+                             tr("Can't update index: internal error"),
+                             QMessageBox::Ok, QMessageBox::NoButton);
+        return;
     }
-    fileToggleIndexingAction->setEnabled(false);
-    actionSpecial_Indexing->setEnabled(false);
 }
