@@ -38,7 +38,6 @@ void RclMain::previewClosed(Preview *w)
     } else {
         LOGDEB("Old preview closed\n");
     }
-    delete w;
 }
 
 // Document up to date check. The main problem we try to solve is
@@ -250,7 +249,12 @@ void RclMain::previewPrevOrNextInTab(Preview * w, int sid, int docnum, bool nxt)
     else 
         docnum--;
     if (docnum < 0 || !m_source || docnum >= m_source->getResCnt()) {
-        QApplication::beep();
+        if (!prefs.noBeeps) {
+            LOGDEB("Beeping\n");
+            QApplication::beep();
+        } else {
+            LOGDEB("Not beeping because nobeep is set\n");
+        }
         return;
     }
 
