@@ -12,12 +12,13 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _RECOLL_H_INCLUDED_
 #define _RECOLL_H_INCLUDED_
 
 #include <string>
+#include <memory>
 
 #include "rclconfig.h"
 #include "rcldb.h"
@@ -40,7 +41,7 @@ extern TempFile *rememberTempFile(TempFile);
 extern void forgetTempFile(string &fn);
 extern void deleteAllTempFiles();
 
-extern Rcl::Db *rcldb;
+extern std::shared_ptr<Rcl::Db> rcldb;
 extern int recollNeedsExit;
 extern void startManual(const string& helpindex);
 
@@ -50,6 +51,10 @@ inline std::string qs2utf8s(const QString& qs)
 {
     return std::string((const char *)qs.toUtf8());
 }
+inline std::string qs2u8s(const QString& qs)
+{
+    return std::string((const char *)qs.toUtf8());
+}
 inline QString u8s2qs(const std::string us)
 {
     return QString::fromUtf8(us.c_str());
@@ -58,6 +63,9 @@ inline QString u8s2qs(const std::string us)
 /** Specialized version of the qt file dialog. Can't use getOpenFile()
    etc. cause they hide dot files... */
 extern QString myGetFileName(bool isdir, QString caption = QString(),
-			     bool filenosave = false);
+			     bool filenosave = false,
+                             QString dirlocation = QString(),
+                             QString dlftnm = QString()
+    );
 
 #endif /* _RECOLL_H_INCLUDED_ */
