@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include "autoconfig.h"
 
@@ -46,6 +46,7 @@
 #include "wasatorcl.h"
 #include "execmd.h"
 #include "indexer.h"
+#include "fstreewalk.h"
 
 using std::list;
 using std::multimap;
@@ -319,16 +320,9 @@ void SpellW::showStats()
 
     baseWordLE->setText(QString::fromLocal8Bit(theconfig->getDbDir().c_str()));
 
-    ExecCmd cmd;
-    vector<string> args; 
-    int status;
-    args.push_back("-sk");
-    args.push_back(theconfig->getDbDir());
-    string output;
-    status = cmd.doexec("du", args, 0, &output);
-    long long dbkbytes = 0;
-    if (!status) {
-	dbkbytes = atoll(output.c_str());
+    int64_t dbkbytes = fsTreeBytes(theconfig->getDbDir()) / 1024;
+    if (dbkbytes < 0) {
+	dbkbytes = 0;
     }
     resTW->setRowCount(row+1);
     resTW->setItem(row, 0,
@@ -344,7 +338,7 @@ void SpellW::showStats()
 	string q = string("mime:") + *it;
 	Rcl::SearchData *sd = wasaStringToRcl(theconfig, "", q, reason);
 	std::shared_ptr<Rcl::SearchData> rq(sd);
-	Rcl::Query query(rcldb);
+	Rcl::Query query(rcldb.get());
 	if (!query.setQuery(rq)) {
 	    LOGERR("Query setup failed: "  << (query.getReason()) << "" );
 	    return;
