@@ -12,13 +12,14 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include <QAction>
 #include <QMenu>
 
 #include "systray.h"
 #include "rclmain_w.h"
+#include "log.h"
 
 void RclTrayIcon::init()
 {
@@ -27,16 +28,36 @@ void RclTrayIcon::init()
      
     connect(restoreAction, SIGNAL(triggered()), this, SLOT(onRestore()));
     connect(quitAction, SIGNAL(triggered()), m_mainw, SLOT(fileExit()));
-
     QMenu *trayIconMenu = new QMenu(0);
     trayIconMenu->addAction(restoreAction);
     trayIconMenu->addAction(quitAction);
     setContextMenu(trayIconMenu);
+
+    connect(this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
+            this, SLOT(onActivated(QSystemTrayIcon::ActivationReason)));
 }
 
 void RclTrayIcon::onRestore()
 {
     // Hide and show to restore on current desktop
     m_mainw->hide();
-    m_mainw->show();
+    switch (prefs.showmode) {
+    case PrefsPack::SHOW_NORMAL: m_mainw->show(); break;
+    case PrefsPack::SHOW_MAX: m_mainw->showMaximized(); break;
+    case PrefsPack::SHOW_FULL: m_mainw->showFullScreen(); break;
+    }
+}
+
+void RclTrayIcon::onActivated(QSystemTrayIcon::ActivationReason reason)
+{
+    LOGDEB("RclTrayIcon::onActivated: reason " << reason << std::endl);
+    switch (reason) {
+    case QSystemTrayIcon::DoubleClick:
+    case QSystemTrayIcon::Trigger:
+    case QSystemTrayIcon::MiddleClick:
+        onRestore();
+        break;
+    default:
+        return;
+    }
 }
