@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _SYSTRAY_H_INCLUDED_
 #define _SYSTRAY_H_INCLUDED_
@@ -33,7 +33,7 @@ class RclTrayIcon : public QSystemTrayIcon {
     }
 public slots:
     void onRestore();
-
+    void onActivated(QSystemTrayIcon::ActivationReason reason);
 private:
     void init();
     RclMain *m_mainw;
