@@ -30,7 +30,7 @@ using std::list;
 
 DocSequenceDb::DocSequenceDb(std::shared_ptr<Rcl::Db> db,
                              std::shared_ptr<Rcl::Query> q, const string &t, 
-			     std::shared_ptr<Rcl::SearchData> sdata) 
+                             std::shared_ptr<Rcl::SearchData> sdata) 
     : DocSequence(t), m_db(db), m_q(q), m_sdata(sdata), m_fsdata(sdata),
       m_rescnt(-1), 
       m_queryBuildAbstract(true),
@@ -56,7 +56,7 @@ bool DocSequenceDb::getDoc(int num, Rcl::Doc &doc, string *sh)
 {
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return false;
+        return false;
     if (sh) sh->erase();
     return m_q->getDoc(num, doc);
 }
@@ -65,9 +65,9 @@ int DocSequenceDb::getResCnt()
 {
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return false;
+        return false;
     if (m_rescnt < 0) {
-	m_rescnt= m_q->getResCnt();
+        m_rescnt= m_q->getResCnt();
     }
     return m_rescnt;
 }
@@ -76,32 +76,33 @@ static const string cstr_mre("[...]");
 
 // This one only gets called to fill-up the snippets window
 // We ignore most abstract/snippets preferences.
-bool DocSequenceDb::getAbstract(Rcl::Doc &doc, vector<Rcl::Snippet>& vpabs)
+bool DocSequenceDb::getAbstract(Rcl::Doc &doc, vector<Rcl::Snippet>& vpabs,
+                                int maxlen, bool sortbypage)
 {
-    LOGDEB("DocSequenceDb::getAbstract/pair\n" );
+    LOGDEB("DocSequenceDb::getAbstract/pair\n");
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return false;
+        return false;
 
     // Have to put the limit somewhere. 
-    int maxoccs = 1000;
     int ret = Rcl::ABSRES_ERROR;
     if (m_q->whatDb()) {
-	ret = m_q->makeDocAbstract(doc, vpabs, maxoccs, 
-				   m_q->whatDb()->getAbsCtxLen()+ 2);
+        ret = m_q->makeDocAbstract(
+            doc, vpabs, maxlen, m_q->whatDb()->getAbsCtxLen() + 2, sortbypage);
     } 
-    LOGDEB("DocSequenceDb::getAbstract: got ret "  << (ret) << " vpabs len "  << (vpabs.size()) << "\n" );
+    LOGDEB("DocSequenceDb::getAbstract: got ret " << ret << " vpabs len " <<
+           vpabs.size() << "\n");
     if (vpabs.empty()) {
-	return true;
+        return true;
     }
 
     // If the list was probably truncated, indicate it.
     if (ret & Rcl::ABSRES_TRUNC) {
-	vpabs.push_back(Rcl::Snippet(-1, cstr_mre));
+        vpabs.push_back(Rcl::Snippet(-1, cstr_mre));
     } 
     if (ret & Rcl::ABSRES_TERMMISS) {
-	vpabs.insert(vpabs.begin(), 
-		     Rcl::Snippet(-1, "(Words missing in snippets)"));
+        vpabs.insert(vpabs.begin(), 
+                     Rcl::Snippet(-1, "(Words missing in snippets)"));
     }
 
     return true;
@@ -111,13 +112,13 @@ bool DocSequenceDb::getAbstract(Rcl::Doc &doc, vector<string>& vabs)
 {
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return false;
+        return false;
     if (m_q->whatDb() &&
-	m_queryBuildAbstract && (doc.syntabs || m_queryReplaceAbstract)) {
-	m_q->makeDocAbstract(doc, vabs);
+        m_queryBuildAbstract && (doc.syntabs || m_queryReplaceAbstract)) {
+        m_q->makeDocAbstract(doc, vabs);
     }
     if (vabs.empty())
-	vabs.push_back(doc.meta[Rcl::Doc::keyabs]);
+        vabs.push_back(doc.meta[Rcl::Doc::keyabs]);
     return true;
 }
 
@@ -125,9 +126,9 @@ int DocSequenceDb::getFirstMatchPage(Rcl::Doc &doc, string& term)
 {
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return false;
+        return false;
     if (m_q->whatDb()) {
-	return m_q->getFirstMatchPage(doc, term);
+        return m_q->getFirstMatchPage(doc, term);
     }
     return -1;
 }
@@ -136,7 +137,7 @@ list<string> DocSequenceDb::expand(Rcl::Doc &doc)
 {
     std::unique_lock<std::mutex> locker(o_dblock);
     if (!setQuery())
-	return list<string>();
+        return list<string>();
     vector<string> v = m_q->expand(doc);
     return list<string>(v.begin(), v.end());
 }
@@ -145,58 +146,58 @@ string DocSequenceDb::title()
 {
     string qual;
     if (m_isFiltered && !m_isSorted)
-	qual = string(" (") + o_filt_trans + string(")");
+        qual = string(" (") + o_filt_trans + string(")");
     else if (!m_isFiltered && m_isSorted)
-	qual = string(" (") + o_sort_trans + string(")");
+        qual = string(" (") + o_sort_trans + string(")");
     else if (m_isFiltered && m_isSorted)
-	qual = string(" (") + o_sort_trans + string(",") + o_filt_trans + 
+        qual = string(" (") + o_sort_trans + string(",") + o_filt_trans + 
             string(")");
     return DocSequence::title() + qual;
 }
 
 bool DocSequenceDb::setFiltSpec(const DocSeqFiltSpec &fs) 
 {
-    LOGDEB("DocSequenceDb::setFiltSpec\n" );
+    LOGDEB("DocSequenceDb::setFiltSpec\n");
     std::unique_lock<std::mutex> locker(o_dblock);
     if (fs.isNotNull()) {
-	// We build a search spec by adding a filtering layer to the base one.
-	m_fsdata = std::shared_ptr<Rcl::SearchData>(
-	    new Rcl::SearchData(Rcl::SCLT_AND, m_sdata->getStemLang()));
-	Rcl::SearchDataClauseSub *cl = 
-	    new Rcl::SearchDataClauseSub(m_sdata);
-	m_fsdata->addClause(cl);
+        // We build a search spec by adding a filtering layer to the base one.
+        m_fsdata = std::shared_ptr<Rcl::SearchData>(
+            new Rcl::SearchData(Rcl::SCLT_AND, m_sdata->getStemLang()));
+        Rcl::SearchDataClauseSub *cl = 
+            new Rcl::SearchDataClauseSub(m_sdata);
+        m_fsdata->addClause(cl);
     
-	for (unsigned int i = 0; i < fs.crits.size(); i++) {
-	    switch (fs.crits[i]) {
-	    case DocSeqFiltSpec::DSFS_MIMETYPE:
-		m_fsdata->addFiletype(fs.values[i]);
-		break;
-	    case DocSeqFiltSpec::DSFS_QLANG:
-	    {
-		if (!m_q)
-		    break;
-		    
-		string reason;
-		Rcl::SearchData *sd = 
-		    wasaStringToRcl(m_q->whatDb()->getConf(), 
-				    m_sdata->getStemLang(),
-				    fs.values[i], reason);
-		if (sd)  {
-		    Rcl::SearchDataClauseSub *cl1 = 
-			new Rcl::SearchDataClauseSub(
-			    std::shared_ptr<Rcl::SearchData>(sd));
-		    m_fsdata->addClause(cl1);
-		}
-	    }
-	    break;
-	    default:
-		break;
-	    }
-	}
-	m_isFiltered = true;
+        for (unsigned int i = 0; i < fs.crits.size(); i++) {
+            switch (fs.crits[i]) {
+            case DocSeqFiltSpec::DSFS_MIMETYPE:
+                m_fsdata->addFiletype(fs.values[i]);
+                break;
+            case DocSeqFiltSpec::DSFS_QLANG:
+            {
+                if (!m_q)
+                    break;
+                    
+                string reason;
+                Rcl::SearchData *sd = 
+                    wasaStringToRcl(m_q->whatDb()->getConf(), 
+                                    m_sdata->getStemLang(),
+                                    fs.values[i], reason);
+                if (sd)  {
+                    Rcl::SearchDataClauseSub *cl1 = 
+                        new Rcl::SearchDataClauseSub(
+                            std::shared_ptr<Rcl::SearchData>(sd));
+                    m_fsdata->addClause(cl1);
+                }
+            }
+            break;
+            default:
+                break;
+            }
+        }
+        m_isFiltered = true;
     } else {
-	m_fsdata = m_sdata;
-	m_isFiltered = false;
+        m_fsdata = m_sdata;
+        m_isFiltered = false;
     }
     m_needSetQuery = true;
     return true;
@@ -204,14 +205,15 @@ bool DocSequenceDb::setFiltSpec(const DocSeqFiltSpec &fs)
 
 bool DocSequenceDb::setSortSpec(const DocSeqSortSpec &spec) 
 {
-    LOGDEB("DocSequenceDb::setSortSpec: fld ["  << (spec.field) << "] "  << (spec.desc ? "desc" : "asc") << "\n" );
+    LOGDEB("DocSequenceDb::setSortSpec: fld [" << spec.field << "] " <<
+           (spec.desc ? "desc" : "asc") << "\n");
     std::unique_lock<std::mutex> locker(o_dblock);
     if (spec.isNotNull()) {
-	m_q->setSortBy(spec.field, !spec.desc);
-	m_isSorted = true;
+        m_q->setSortBy(spec.field, !spec.desc);
+        m_isSorted = true;
     } else {
-	m_q->setSortBy(string(), true);
-	m_isSorted = false;
+        m_q->setSortBy(string(), true);
+        m_isSorted = false;
     }
     m_needSetQuery = true;
     return true;
@@ -220,14 +222,15 @@ bool DocSequenceDb::setSortSpec(const DocSeqSortSpec &spec)
 bool DocSequenceDb::setQuery()
 {
     if (!m_needSetQuery)
-	return true;
+        return true;
 
     m_needSetQuery = false;
     m_rescnt = -1;
     m_lastSQStatus = m_q->setQuery(m_fsdata);
     if (!m_lastSQStatus) {
-	m_reason = m_q->getReason();
-	LOGERR("DocSequenceDb::setQuery: rclquery::setQuery failed: "  << (m_reason) << "\n" );
+        m_reason = m_q->getReason();
+        LOGERR("DocSequenceDb::setQuery: rclquery::setQuery failed: " <<
+               m_reason << "\n");
     }
     return m_lastSQStatus;
 }
@@ -236,9 +239,9 @@ bool DocSequenceDb::docDups(const Rcl::Doc& doc, std::vector<Rcl::Doc>& dups)
 {
     if (m_q->whatDb()) {
         std::unique_lock<std::mutex> locker(o_dblock);
-	return m_q->whatDb()->docDups(doc, dups);
+        return m_q->whatDb()->docDups(doc, dups);
     } else {
-	return false;
+        return false;
     }
 }
 
