@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #include <algorithm>
 
@@ -32,9 +32,8 @@ public:
     { 
 	LOGDEB1("Comparing .. \n" );
 
-	map<string,string>::const_iterator xit, yit;
-	xit = x->meta.find(ss.field);
-	yit = y->meta.find(ss.field);
+	const auto xit = x->meta.find(ss.field);
+	const auto yit = y->meta.find(ss.field);
 	if (xit == x->meta.end() || yit == y->meta.end())
 	    return 0;
 	return ss.desc ? yit->second < xit->second : xit->second < yit->second;
