@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _DB_H_INCLUDED_
 #define _DB_H_INCLUDED_
@@ -189,6 +189,9 @@ public:
     /** Return existing stemming databases */
     vector<string> getStemLangs();
 
+    /** Check if index stores the documents' texts. Only valid after open */
+    bool storesDocText();
+    
     /** Test word for spelling correction candidate: not too long, no 
      * special chars... 
      * @param with_aspell test for use with aspell, else for xapian speller
@@ -341,6 +344,12 @@ public:
        decide if we can update the index for it */
     bool fromMainIndex(const Doc& doc);
 
+    /** Retrieve the stored doc text. This returns false if the index does not
+        store raw text or other problems (discriminate with storesDocText(). 
+        On success, the data is stored in doc.text
+    */
+    bool getDocRawText(Doc& doc);
+    
     /** Retrieve an index designator for the document result. This is used 
      * by the GUI document history feature for remembering where a
      * doc comes from and allowing later retrieval (if the ext index
@@ -446,6 +455,12 @@ public:
      */
     bool getSubDocs(const Doc& idoc, vector<Doc>& subdocs);
 
+    /** Get container (top level file) document. 
+     *
+     * If the input is not a subdocument, this returns a copy of the input.
+     */
+    bool getContainerDoc(const Doc &idoc, Doc& ctdoc);
+    
     /** Get duplicates (md5) of document */
     bool docDups(const Doc& idoc, std::vector<Doc>& odocs);
 
@@ -483,7 +498,14 @@ public:
 
     // Use empty fn for no synonyms
     bool setSynGroupsFile(const std::string& fn);
-    
+
+    // Mark all documents with an UDI having input as prefix as
+    // existing.  Only works if the UDIs for the store are
+    // hierarchical of course.  Used by FsIndexer to avoid purging
+    // files for a topdir which is on a removable file system and
+    // currently unmounted (topdir does not exist or is empty.
+    bool udiTreeMarkExisting(const string& udi);
+
     /* This has to be public for access by embedded Query::Native */
     Native *m_ndb; 
 private:
