@@ -90,8 +90,15 @@ public:
      */
     bool setQuery(std::shared_ptr<SearchData> q);
 
-    /** Get results count for current query */
-    int getResCnt();
+
+    /**  Get results count for current query.
+     *
+     * @param useestimate Use get_matches_estimated() if true, else 
+     *     get_matches_lower_bound()
+     * @param checkatleast checkatleast parameter to get_mset(). Use -1 for 
+     *     full scan.
+     */
+    int getResCnt(int checkatleast=1000, bool useestimate=false);
 
     /** Get document at rank i in current query results. */
     bool getDoc(int i, Doc &doc, bool fetchtext = false);
@@ -107,7 +114,7 @@ public:
     bool makeDocAbstract(const Doc &doc, std::vector<std::string>& abstract);
     // Returned as a vector of pair<page,snippet> page is 0 if unknown
     int makeDocAbstract(const Doc &doc, std::vector<Snippet>& abst, 
-                        int maxoccs= -1, int ctxwords = -1);
+                        int maxoccs= -1, int ctxwords = -1, bool sortbypage=false);
     /** Retrieve page number for first match for "significant" query term 
      *  @param term returns the chosen term */
     int getFirstMatchPage(const Doc &doc, std::string& term);
