@@ -1,18 +1,18 @@
 /* Copyright (C) 2003-2016 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   it under the terms of the GNU Lesser General Public License as published by
+ *   the Free Software Foundation; either version 2.1 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *   GNU Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
+ *   You should have received a copy of the GNU Lesser General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifdef BUILDING_RECOLL
 #include "autoconfig.h"
@@ -42,7 +42,11 @@
 
 #include "pathut.h"
 #include "smallut.h"
+#ifdef MDU_INCLUDE_LOG
+#include MDU_INCLUDE_LOG
+#else
 #include "log.h"
+#endif
 
 using namespace std;
 
@@ -503,6 +507,13 @@ int ConfSimple::eraseKey(const string& sk)
     return write();
 }
 
+int ConfSimple::clear()
+{
+    m_submaps.clear();
+    m_order.clear();
+    return write();
+}
+
 // Walk the tree, calling user function at each node
 ConfSimple::WalkerCode
 ConfSimple::sortwalk(WalkerCode(*walker)(void *, const string&, const string&),
@@ -688,6 +699,13 @@ bool ConfSimple::commentsAsXML(ostream& out)
             }
             break;
         }
+        case ConfLine::CFL_SK:
+            out << "<subkey>" << it->m_data << "</subkey>" << endl;
+            break;
+        case ConfLine::CFL_VAR:
+            out << "<varsetting>" << it->m_data << " = " <<
+                it->m_value << "</varsetting>" << endl;
+            break;
         default:
             break;
         }
