@@ -30,8 +30,13 @@ typedef struct MD5Context {
 
 void	 MD5Init(MD5_CTX *);
 void	 MD5Update(MD5_CTX *, const uint8_t *, size_t);
-void	 MD5Pad(MD5_CTX *);
 void	 MD5Final(uint8_t [MD5_DIGEST_LENGTH], MD5_CTX *);
-void	 MD5Transform(uint32_t [4], const uint8_t [MD5_BLOCK_LENGTH]);
+
+/** md5 c++ utility wrappers */
+#include <string>
+extern void MD5Final(std::string& digest, MD5_CTX *);
+extern std::string& MD5String(const std::string& data, std::string& digest);
+extern std::string& MD5HexPrint(const std::string& digest, std::string& xdigest);
+extern std::string& MD5HexScan(const std::string& xdigest, std::string& digest);
 
 #endif /* _MD5_H_ */
