@@ -1,18 +1,18 @@
 /* Copyright (C) 2002 J.F. Dockes
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   it under the terms of the GNU Lesser General Public License as published by
+ *   the Free Software Foundation; either version 2.1 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *   GNU Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
+ *   You should have received a copy of the GNU Lesser General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 // Wrapper classes for the socket interface
@@ -51,7 +51,11 @@
 
 #include <map>
 
+#ifdef MDU_INCLUDE_LOG
+#include MDU_INCLUDE_LOG
+#else
 #include "log.h"
+#endif
 
 using namespace std;
 
@@ -701,7 +705,10 @@ void NetconData::cancelReceive()
 {
     if (m_wkfds[1] >= 0) {
         LOGDEB2("NetconData::cancelReceive: writing to " << m_wkfds[1] << endl);
-        ::write(m_wkfds[1], "!", 1);
+        // We can't do a thing about the ::write return value, the
+        // following nonsense is for cancelling warnings
+        int ret = ::write(m_wkfds[1], "!", 1);
+        ret = ret;
     }
 }
 
@@ -750,7 +757,10 @@ int NetconData::receive(char *buf, int cnt, int timeo)
         
         if (cancellable && FD_ISSET(m_wkfds[0], &rd)) {
             char b[100];
-            read(m_wkfds[0], b, 100);
+            // We can't do a thing about the return value, the
+            // following nonsense is for cancelling warnings
+            int ret = ::read(m_wkfds[0], b, 100);
+            ret = ret;
             return Cancelled;
         }
 
