@@ -1,18 +1,18 @@
 /* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   it under the terms of the GNU Lesser General Public License as published by
+ *   the Free Software Foundation; either version 2.1 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *   GNU Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
+ *   You should have received a copy of the GNU Lesser General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _PATHUT_H_INCLUDED_
 #define _PATHUT_H_INCLUDED_
@@ -87,10 +87,20 @@ extern int path_fileprops(const std::string path, struct stat *stp,
 /// Returns true if last elt could be checked to exist. False may mean that
 /// the file/dir does not exist or that an error occurred.
 extern bool path_exists(const std::string& path);
+/// Same but must be readable
+extern bool path_readable(const std::string& path);
 
 /// Return separator for PATH environment variable
 extern std::string path_PATHsep();
 
+#ifdef _WIN32
+#define SYSPATH(PATH, SPATH) wchar_t PATH ## _buf[2048];      \
+    utf8towchar(PATH, PATH ## _buf, 2048);                    \
+    wchar_t *SPATH = PATH ## _buf;
+#else
+#define SYSPATH(PATH, SPATH) const char *SPATH = PATH.c_str()
+#endif
+
 /// Dump directory
 extern bool readdir(const std::string& dir, std::string& reason,
                     std::set<std::string>& entries);
@@ -120,10 +130,29 @@ extern bool path_isdesc(const std::string& top, const std::string& sub);
 /// Turn absolute path into file:// url
 extern std::string path_pathtofileurl(const std::string& path);
 
+/// URI parser, loosely from rfc2396.txt
+class ParsedUri {
+public:
+    ParsedUri(std::string uri);
+    bool parsed{false};
+    std::string scheme;
+    std::string user;
+    std::string pass;
+    std::string host;
+    std::string port;
+    std::string path;
+    std::string query;
+    std::vector<std::pair<std::string,std::string>> parsedquery;
+    std::string fragment;
+};
+
 #ifdef _WIN32
 /// Convert \ separators to /
 void path_slashize(std::string& s);
 void path_backslashize(std::string& s);
+#include "safeunistd.h"
+#else
+#include <unistd.h>
 #endif
 
 /// Lock/pid file class. This is quite close to the pidfile_xxx
