@@ -12,7 +12,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifndef _TRANSCODE_H_INCLUDED_
 #define _TRANSCODE_H_INCLUDED_
@@ -36,4 +36,9 @@ extern bool transcode(const std::string &in, std::string &out,
 		      const std::string &ocode, 
 		      int *ecnt = 0);
 
+#ifdef _WIN32
+extern bool wchartoutf8(const wchar_t *in, std::string& out);
+extern bool utf8towchar(const std::string& in, wchar_t *out, size_t obytescap);
+#endif
+
 #endif /* _TRANSCODE_H_INCLUDED_ */
